You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@kudu.apache.org by to...@apache.org on 2016/04/12 18:20:34 UTC

incubator-kudu git commit: KUDU-1381: Upgrade bitshuffle to the latest

Repository: incubator-kudu
Updated Branches:
  refs/heads/master 00ac42f54 -> ce11938a2


KUDU-1381: Upgrade bitshuffle to the latest

My recent prs in bitshuffle resolved some issues(e.g., dependency and compile errors),
so it'd be better to upgrade the version.

Change-Id: I1da6817f857cba4a3648adee1cd6adcc1a11f61e
Reviewed-on: http://gerrit.cloudera.org:8080/2765
Tested-by: Kudu Jenkins
Reviewed-by: Todd Lipcon <to...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/incubator-kudu/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kudu/commit/ce11938a
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kudu/tree/ce11938a
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kudu/diff/ce11938a

Branch: refs/heads/master
Commit: ce11938a2e0ad839989a9b13fd4b6ccfdb42f419
Parents: 00ac42f
Author: Takeshi YAMAMURO <li...@gmail.com>
Authored: Fri Mar 25 10:20:31 2016 +0900
Committer: Todd Lipcon <to...@apache.org>
Committed: Tue Apr 12 16:20:11 2016 +0000

----------------------------------------------------------------------
 thirdparty/build-definitions.sh | 8 +++++---
 thirdparty/vars.sh              | 4 ++--
 2 files changed, 7 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/ce11938a/thirdparty/build-definitions.sh
----------------------------------------------------------------------
diff --git a/thirdparty/build-definitions.sh b/thirdparty/build-definitions.sh
index afedcec..4840df7 100644
--- a/thirdparty/build-definitions.sh
+++ b/thirdparty/build-definitions.sh
@@ -220,10 +220,12 @@ build_lz4() {
 build_bitshuffle() {
   cd $BITSHUFFLE_DIR
   # bitshuffle depends on lz4, therefore set the flag I$PREFIX/include
-  ${CC:-gcc} $EXTRA_CFLAGS -std=c99 -I$PREFIX/include -O3 -DNDEBUG -fPIC -c bitshuffle.c
-  ar rs bitshuffle.a bitshuffle.o
+  ${CC:-gcc} $EXTRA_CFLAGS -std=c99 -I$PREFIX/include -O3 -DNDEBUG -fPIC -c \
+    src/bitshuffle_core.c src/bitshuffle.c src/iochain.c
+  ar rs bitshuffle.a bitshuffle_core.o bitshuffle.o iochain.o
   cp bitshuffle.a $PREFIX/lib/
-  cp bitshuffle.h $PREFIX/include/
+  cp src/bitshuffle.h $PREFIX/include/bitshuffle.h
+  cp src/bitshuffle_core.h $PREFIX/include/bitshuffle_core.h
 }
 
 build_libev() {

http://git-wip-us.apache.org/repos/asf/incubator-kudu/blob/ce11938a/thirdparty/vars.sh
----------------------------------------------------------------------
diff --git a/thirdparty/vars.sh b/thirdparty/vars.sh
index c8256c7..b682928 100644
--- a/thirdparty/vars.sh
+++ b/thirdparty/vars.sh
@@ -54,8 +54,8 @@ LZ4_VERSION=r130
 LZ4_DIR=$TP_DIR/lz4-lz4-$LZ4_VERSION
 
 # from https://github.com/kiyo-masui/bitshuffle
-# Hash of git: c5c928fe7d4bc5b9391748a8dd29de5a89c3c94a
-BITSHUFFLE_VERSION=c5c928f
+# Hash of git: 55f9b4caec73fa21d13947cacea1295926781440
+BITSHUFFLE_VERSION=55f9b4c
 BITSHUFFLE_DIR=$TP_DIR/bitshuffle-${BITSHUFFLE_VERSION}
 
 ZLIB_VERSION=1.2.8